
#ifndef NETWORKMANAGERQT_EXPORT_H
#define NETWORKMANAGERQT_EXPORT_H

#ifdef NETWORKMANAGERQT_STATIC_DEFINE
#  define NETWORKMANAGERQT_EXPORT
#  define NETWORKMANAGERQT_NO_EXPORT
#else
#  ifndef NETWORKMANAGERQT_EXPORT
#    ifdef KF6NetworkManagerQt_EXPORTS
        /* We are building this library */
#      define NETWORKMANAGERQT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define NETWORKMANAGERQT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef NETWORKMANAGERQT_NO_EXPORT
#    define NETWORKMANAGERQT_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef NETWORKMANAGERQT_DECL_DEPRECATED
#  define NETWORKMANAGERQT_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef NETWORKMANAGERQT_DECL_DEPRECATED_EXPORT
#  define NETWORKMANAGERQT_DECL_DEPRECATED_EXPORT NETWORKMANAGERQT_EXPORT NETWORKMANAGERQT_DECL_DEPRECATED
#endif

#ifndef NETWORKMANAGERQT_DECL_DEPRECATED_NO_EXPORT
#  define NETWORKMANAGERQT_DECL_DEPRECATED_NO_EXPORT NETWORKMANAGERQT_NO_EXPORT NETWORKMANAGERQT_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef NETWORKMANAGERQT_NO_DEPRECATED
#    define NETWORKMANAGERQT_NO_DEPRECATED
#  endif
#endif
#include <networkmanagerqt_version.h>

#undef NETWORKMANAGERQT_DECL_DEPRECATED
#define NETWORKMANAGERQT_DECL_DEPRECATED [[deprecated]]

#undef NETWORKMANAGERQT_DECL_DEPRECATED_EXPORT
#define NETWORKMANAGERQT_DECL_DEPRECATED_EXPORT NETWORKMANAGERQT_EXPORT NETWORKMANAGERQT_DECL_DEPRECATED

#undef NETWORKMANAGERQT_DECL_DEPRECATED_NO_EXPORT
#define NETWORKMANAGERQT_DECL_DEPRECATED_NO_EXPORT NETWORKMANAGERQT_NO_EXPORT NETWORKMANAGERQT_DECL_DEPRECATED

#define NETWORKMANAGERQT_DECL_DEPRECATED_TEXT(text) [[deprecated(text)]]

/* Take any defaults from group settings */
#if !defined(NETWORKMANAGERQT_NO_DEPRECATED) && !defined(NETWORKMANAGERQT_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define NETWORKMANAGERQT_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define NETWORKMANAGERQT_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(NETWORKMANAGERQT_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define NETWORKMANAGERQT_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(NETWORKMANAGERQT_NO_DEPRECATED_WARNINGS) && !defined(NETWORKMANAGERQT_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define NETWORKMANAGERQT_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define NETWORKMANAGERQT_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(NETWORKMANAGERQT_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define NETWORKMANAGERQT_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(NETWORKMANAGERQT_NO_DEPRECATED)
#  undef NETWORKMANAGERQT_DEPRECATED
#  define NETWORKMANAGERQT_DEPRECATED_EXPORT NETWORKMANAGERQT_EXPORT
#  define NETWORKMANAGERQT_DEPRECATED_NO_EXPORT NETWORKMANAGERQT_NO_EXPORT
#elif defined(NETWORKMANAGERQT_NO_DEPRECATED_WARNINGS)
#  define NETWORKMANAGERQT_DEPRECATED
#  define NETWORKMANAGERQT_DEPRECATED_EXPORT NETWORKMANAGERQT_EXPORT
#  define NETWORKMANAGERQT_DEPRECATED_NO_EXPORT NETWORKMANAGERQT_NO_EXPORT
#else
#  define NETWORKMANAGERQT_DEPRECATED NETWORKMANAGERQT_DECL_DEPRECATED
#  define NETWORKMANAGERQT_DEPRECATED_EXPORT NETWORKMANAGERQT_DECL_DEPRECATED_EXPORT
#  define NETWORKMANAGERQT_DEPRECATED_NO_EXPORT NETWORKMANAGERQT_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define NETWORKMANAGERQT_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define NETWORKMANAGERQT_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef NETWORKMANAGERQT_NO_DEPRECATED
#  define NETWORKMANAGERQT_DISABLE_DEPRECATED_BEFORE_AND_AT NETWORKMANAGERQT_VERSION
#endif
#ifdef NETWORKMANAGERQT_NO_DEPRECATED_WARNINGS
#  define NETWORKMANAGERQT_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef NETWORKMANAGERQT_DEPRECATED_WARNINGS_SINCE
#  ifdef NETWORKMANAGERQT_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define NETWORKMANAGERQT_DEPRECATED_WARNINGS_SINCE NETWORKMANAGERQT_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define NETWORKMANAGERQT_DEPRECATED_WARNINGS_SINCE NETWORKMANAGERQT_VERSION
#  endif
#endif

#ifndef NETWORKMANAGERQT_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define NETWORKMANAGERQT_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef NETWORKMANAGERQT_DEPRECATED
#  define NETWORKMANAGERQT_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > NETWORKMANAGERQT_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define NETWORKMANAGERQT_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if NETWORKMANAGERQT_DEPRECATED_WARNINGS_SINCE >= 0x61400
#  define NETWORKMANAGERQT_DEPRECATED_VERSION_6_20(text) NETWORKMANAGERQT_DECL_DEPRECATED_TEXT(text)
#else
#  define NETWORKMANAGERQT_DEPRECATED_VERSION_6_20(text)
#endif
#define NETWORKMANAGERQT_DEPRECATED_VERSION_6(minor, text)      NETWORKMANAGERQT_DEPRECATED_VERSION_6_##minor(text)
#define NETWORKMANAGERQT_DEPRECATED_VERSION(major, minor, text) NETWORKMANAGERQT_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define NETWORKMANAGERQT_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) NETWORKMANAGERQT_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)

#endif /* NETWORKMANAGERQT_EXPORT_H */
